'use strict';

var _assert = require('assert');

var _assert2 = _interopRequireDefault(_assert);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _parser = require('../parser');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var polymerUrl = 'bower_components/polymer/polymer.html';
var localUrlFn = function localUrlFn(ext, bower) {
  var componentName = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'custom-element';

  var url = bower ? 'bower_components/' : '';
  url += componentName + '/' + componentName + '.' + ext;
  return url;
};
var externalUrlFn = function externalUrlFn(ext) {
  return 'https://example.com/path/to/file-name.' + ext;
};

describe('link', function () {
  it('returns local href correctly', function () {
    var href = localUrlFn('html', true);
    var absPath = _path2.default.resolve('', href);
    var html = '<link href="' + href + '" rel="import">';
    var store = (0, _parser.parse)(html, {}, 'test.js');
    var links = Object.keys(store);
    var link = links[0];
    var linkAST = store[link];
    _assert2.default.equal(absPath, link);
    _assert2.default.equal(href, linkAST.urlObject.href);
    _assert2.default.equal(true, linkAST.urlObject.local);
  });
  it('returns external href correctly', function () {
    var href = externalUrlFn('html', true);
    var html = '<link href="' + href + '" rel="import">';
    var store = (0, _parser.parse)(html, {}, 'test.js');
    var links = Object.keys(store);
    var link = links[0];
    var linkAST = store[link];
    _assert2.default.equal(href, link);
    _assert2.default.equal(false, linkAST.urlObject.local);
  });
});

describe('script', function () {
  it('returns local src correctly', function () {
    var href = localUrlFn('js', true);
    var html = '<script src="' + href + '">blah</script>';
    var store = (0, _parser.parse)(html, {}, 'test.js');
    var links = Object.keys(store);
    var link = links[0];
    var linkAST = store[link];
    _assert2.default.equal(href, linkAST.urlObject.href);
    _assert2.default.equal(true, linkAST.urlObject.local);
  });
  it('returns external href correctly', function () {
    var href = externalUrlFn('js', true);
    var html = '<script src="' + href + '">blah</script>';
    var store = (0, _parser.parse)(html, {}, 'test.js');
    var links = Object.keys(store);
    var link = links[0];
    var linkAST = store[link];
    _assert2.default.equal(href, link);
    _assert2.default.equal(false, linkAST.urlObject.local);
  });
  it('skips script without src', function () {
    var html = '<script>blah</script>';
    var store = (0, _parser.parse)(html, {}, 'test.js');
    var links = Object.keys(store);
    _assert2.default.equal(0, links.length);
  });
});