#!/usr/bin/env node
'use strict';

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _meow = require('meow');

var _meow2 = _interopRequireDefault(_meow);

var _filesize = require('filesize');

var _filesize2 = _interopRequireDefault(_filesize);

var _cliTable = require('cli-table');

var _cliTable2 = _interopRequireDefault(_cliTable);

var _lodash = require('lodash');

var _ = _interopRequireWildcard(_lodash);

var _links = require('./links');

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var cli = (0, _meow2.default)('\n    Usage\n      $ weigh <input>\n\n    Options\n      --path, -P  Path to starting file/folder\n\n    Examples\n      $ weigh --path src/index.html\n');

var flags = cli.flags;

var sourcePath = flags.path ? _path2.default.resolve(flags.path) : process.cwd();
var store = {};
var table = new _cliTable2.default({
  head: ['Type', 'Link', 'Size'],
  colWidths: [25, 100, 25],
  style: { head: ['red'], border: ['white'] },
  chars: { 'mid': '', 'left-mid': '', 'mid-mid': '', 'right-mid': '' }
});

try {
  (function () {
    var stat = _fs2.default.statSync(sourcePath);
    var isDir = stat.isDirectory();
    var indexPath = isDir ? _path2.default.resolve(sourcePath, './index.html') : sourcePath;
    var store = {};
    (0, _links.parseFile)(indexPath, store).then(function (r) {
      var astColl = _.values(store);
      var group = _.groupBy(astColl, function (ast) {
        return ast.urlObject.local ? 'local' : 'external';
      });
      if (!group.local && !group.external) {
        console.log('No Links Found');
        return;
      }
      var sortedColl = _.sortBy(group.local, [function (ast) {
        return ast.fileStats.size;
      }]);
      var netIndexSize = stat.size;
      _.each(sortedColl.reverse(), function (ast) {
        netIndexSize += ast.fileStats.size;
        var size = (0, _filesize2.default)(ast.fileStats.size, { base: 10 });
        var absPath = ast.urlObject.absPath;
        var relPath = _path2.default.relative(_path2.default.dirname(indexPath), absPath);
        table.push([ast.tagName, relPath, size]);
      });
      _.each(group.external, function (ast) {
        var absPath = ast.urlObject.absPath;
        table.push([ast.tagName, absPath, 'NA']);
      });
      table.push(['Total', _path2.default.basename(indexPath), (0, _filesize2.default)(netIndexSize, { base: 10 })]);
      console.log(table.toString());
    });
  })();
} catch (e) {
  console.log(e);
}