'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.processScript = exports.processLink = exports.pushLink = exports.getLinks = exports.parse = exports.getAST = undefined;

var _parse = require('parse5');

var _url = require('url');

var _url2 = _interopRequireDefault(_url);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _lodash = require('lodash');

var _ = _interopRequireWildcard(_lodash);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var defaultOptions = { locationInfo: true };
var getAST = exports.getAST = function getAST(html) {
  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultOptions;

  var ast = (0, _parse.parse)(html, options);
  return ast;
};
var parse = exports.parse = function parse(html) {
  var store = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  var filePath = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

  var ast = getAST(html);
  getLinks(ast, store, filePath);
  return store;
};

var getLinks = exports.getLinks = function getLinks(ast) {
  var store = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  var filePath = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

  if (!ast || !ast.childNodes) {
    return store;
  }
  var childNodes = ast.childNodes;
  _.each(childNodes, function (child) {
    switch (child.tagName) {
      case 'template':
        {
          var content = _parse.treeAdapters.default.getTemplateContent(child);
          getLinks(content, store, filePath);
        }
        break;
      case 'link':
        {
          var link = processLink(child);
          pushLink(link, store, filePath);
        }
        break;
      case 'script':
        {
          var _link = processScript(child);
          if (_link) {
            pushLink(_link, store, filePath);
          }
        }
        break;
      // TODO style
      // case 'style': {
      // const links = processStyle(child);
      // if(links) {
      // Object.values(store).concat(link);
      // }
      // }
      // break;

      default:
        {
          if (child.tagName) {
            getLinks(child, store, filePath);
          }
        }
        break;
    };
  });
  return store;
};
var pushLink = exports.pushLink = function pushLink(linkAST, store, filePath) {
  if (!linkAST.urlObject) {
    throw new Error('no href found in link at line ' + linkAST.__location.col + ' in file ' + filePath);
  }
  var href = linkAST.urlObject.href;
  var __location = linkAST.__location;
  var occurance = {
    filePath: filePath,
    __location: __location
  };
  var absPath = linkAST.urlObject.local ? _path2.default.resolve(_path2.default.dirname(filePath), href) : href;

  if (!store[absPath]) {
    var link = _.omit(linkAST, '__location');
    link.occurances = [occurance];
    link.urlObject.absPath = absPath;
    store[absPath] = link;
  } else {
    store[absPath].occurances.push(occurance);
  }
  return store;
};
var orphanAST = function orphanAST(ast) {
  return _.omit(ast, 'parentNode', 'childNodes');
};
var formatUrl = function formatUrl(href) {
  var urlObject = _url2.default.parse(href);
  urlObject.local = !urlObject.protocol;
  return urlObject;
};
var processLink = exports.processLink = function processLink(ast) {
  var hrefAttr = _.find(ast.attrs, function (v) {
    return v.name === 'href';
  });
  var link = orphanAST(ast);
  if (hrefAttr) {
    var href = hrefAttr.value;
    link.urlObject = formatUrl(href);
  }
  return link;
};
var processScript = exports.processScript = function processScript(ast) {
  var importSource = _.find(ast.attrs, function (v) {
    return v.name === 'src';
  });
  if (importSource && importSource.value) {
    var script = orphanAST(ast);
    script.urlObject = formatUrl(importSource.value);
    return script;
  }
  return;
};